@@ -1459,6 +1459,14 @@ impl Error {
             message: status.message().to_string(),
         }
     }
+
+    pub fn is_access_denied(&self) -> bool {
+        if let Error::AccessDenied = self {
+            return true;
+        }
+
+        false
+    }
 }
 
 #[derive(Error, Debug, Clone)]
@@ -1497,6 +1505,13 @@ impl SubscriptionFilter {
         temp
     }
 
+    pub fn exclude_system_events(self) -> Self {
+        Self {
+            regex: Some("^[^\\$].*".to_string()),
+            ..self
+        }
+    }
+
     pub fn max(self, max: u32) -> Self {
         SubscriptionFilter {
             max: Some(max),
